#
# spec file for package apache2-mod_pagespeed
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define module_dir /srv/www/mod_pagespeed
%define log_dir %{_localstatedir}/log/pagespeed
%define	module_data_dir	%{module_dir}/cache
%define ssl_cert_dir %{_sysconfdir}/ssl/certs/
%define ssl_cert_file %{_sysconfdir}/apache2/ssl.crt/server.crt
%define use_system_icu 1
%define use_system_libs 1
%define src_ver 1.11.33.2
%define svn_rev 0
Name:           apache2-mod_pagespeed
Version:        %{src_ver}
Release:        2.7
Summary:        Apache module for rewriting web pages to reduce latency and bandwidth
License:        Apache-2.0
Group:          Productivity/Networking/Web/Servers
Url:            http://code.google.com/p/modpagespeed/
Source:         https://dl.google.com/dl/linux/mod-pagespeed/tar/beta/mod-pagespeed-stable-%{version}-r%{svn_rev}.tar.bz2
Patch1:         apache24-configuration.patch
Patch2:         gcc5.patch
Patch3:         apache2-mod_pagespeed-older-openssl.patch
BuildRequires:  apache2-devel
BuildRequires:  apache-rpm-macros
BuildRequires:  bzip2
BuildRequires:  curl
BuildRequires:  gcc-c++
BuildRequires:  gperf
BuildRequires:  apr-util-devel
BuildRequires:  apr-devel
BuildRequires:  libicu-devel
# TODO-libpng-turbo
BuildRequires:  libjpeg8-devel
BuildRequires:  libpng12-compat-devel
BuildRequires:  openssl-devel
BuildRequires:  python-base
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libssl)
Requires:       apache2
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
mod_pagespeed is built on PageSpeed Optimization Libraries, deployed across 100,000+ web-sites,
and provided by popular hosting and CDN providers such as DreamHost, GoDaddy, EdgeCast, and others.
There are 40+ available optimizations filters, which include:

Image optimization, compression, and resizing
CSS & JavaScript concatenation, minification, and inlining
Cache extension, domain sharding, and domain rewriting
Deferred loading of JavaScript and image resources
and many others...

%prep
%setup -q -n modpagespeed-%{version}/src
%patch2
build/gyp_chromium -Duse_system_libs=%{use_system_libs} -Duse_system_icu=%{use_system_icu} -Dsystem_include_path_apr=${BUILD_ROOT}%{_includedir}/apr-1 -Dsystem_include_path_httpd=${BUILD_ROOT}%{apache_includedir} -Dsystem_include_path_aprutil=${BUILD_ROOT}%{_includedir}/apr-1
%patch1
%patch3 -p1

%build
make %{?_smp_mflags} BUILDTYPE=Release

%install
install -d -m 755 %{buildroot}%{_libdir}/apache2
strip out/Release/libmod_pagespeed.so
install -m 644 out/Release/libmod_pagespeed.so %{buildroot}%{_libdir}/apache2/mod_pagespeed.so

install -d -m 755 %{buildroot}%{module_data_dir}
install -d -m 755 %{buildroot}%{module_data_dir}

install -d -m 755 %{buildroot}%{log_dir}

install -d -m 755 %{buildroot}%{apache_sysconfdir}/conf.d
install -m 644 out/Release/install/common/pagespeed.conf.template %{buildroot}%{apache_sysconfdir}/conf.d/mod_pagespeed.conf
sed -i 's|@@MOD_PAGESPEED_CACHE@@|%{module_data_dir}|' %{buildroot}%{apache_sysconfdir}/conf.d/mod_pagespeed.conf
sed -i 's|@@MOD_PAGESPEED_LOG@@|%{log_dir}|' %{buildroot}%{apache_sysconfdir}/conf.d/mod_pagespeed.conf
sed -i 's|@@SSL_CERT_DIR@@|%{ssl_cert_dir}|' %{buildroot}%{apache_sysconfdir}/conf.d/mod_pagespeed.conf
sed -i 's|@@SSL_CERT_FILE_COMMAND@@|ModPagespeedSslCertFile %{ssl_cert_file}|' %{buildroot}%{apache_sysconfdir}/conf.d/mod_pagespeed.conf

sed -i 's|@@MOD_PAGESPEED_STATS_LOG@@|%{_localstatedir}/log/apache2/mod_pagespeed_stats.log|' %{buildroot}%{apache_sysconfdir}/conf.d/mod_pagespeed.conf

%check
set +x
# create world writeable dir for testing
mkdir -p %{apache_test_module_dir}
# create test conf there
cat << EOF > %{apache_test_module_dir}/mod_pagespeed-test.conf
ModPagespeed on
ModPagespeedInheritVHostConfig  on
AddOutputFilterByType           MOD_PAGESPEED_OUTPUT_FILTER text/html
ModPagespeedFileCachePath       "%{apache_test_module_dir}/srv/www/mod_pagespeed/cache/"
ModPagespeedLogDir              "%{apache_test_module_dir}/var/log/pagespeed"
ModPagespeedFileCacheInodeLimit 500000
<Location /pagespeed_admin>
  Require local
  SetHandler pagespeed_admin
</Location>
ModPagespeedStatisticsLogging on
ModPagespeedMessageBufferSize 100000 
EOF
# run apache test instance
%apache_test_module_start_apache -m filter:pagespeed -i mod_pagespeed-test.conf
# curl test document
%apache_test_module_curl -d /pagespeed_admin/ -o %{apache_test_module_dir}/pagespeed_admin.txt
# perform tests on that document
echo
echo 'Testing /pagespeed_admin/ output'
exit_code=0
grep '<b>Pagespeed Admin</b>' %{apache_test_module_dir}/pagespeed_admin.txt || exit_code=1
if [ $exit_code -eq 0 ]; then
    echo 'PASS'
  else
    echo 'FAIL'
fi
echo
# stop apache test instance
%apache_test_module_stop_apache
set -x
# exit the test result
exit $exit_code

%files
%defattr(-,root,root)
%{_libdir}
%{_libdir}/apache2/mod_pagespeed.so
%{module_dir}
%{module_data_dir}
%attr(755, wwwrun, www) %{module_data_dir}
%{apache_sysconfdir}
%config(noreplace) %{apache_sysconfdir}/conf.d/mod_pagespeed.conf
%attr(700, wwwrun, www) %{log_dir}

%changelog
* Tue Dec 19 2017 pgajdos@suse.com
- buildrequire apr-util-devel instead of libapr-util1-devel
- buildrequire apr-devel instead of libapr1-devel
* Thu Jun 30 2016 pgajdos@suse.com
- Update to upstream 1.11.32.2
  * fixes c++ error (error: redefinition of 'class std::tuple and
    similar) on factory
  * added https://gist.github.com/crowell/507678b6b180dab203fc6c0756230855
    + apache2-mod_pagespeed-older-openssl.patch
* Tue Jan 12 2016 pgajdos@suse.com
- %%check: we build mod_pagespeed only with 2.4, so no need
  for access syntax conditional
* Thu Dec 10 2015 robert.munteanu@gmail.com
- Update to upstream 1.9.32.11
  * Update BoringSSL to pull in OpenSSL changes
- Removed fix-32-bit-compilation.patch, upstreamed
* Tue Nov  3 2015 robert.munteanu@gmail.com
- Added fix-32-bit-compilation.patch
* Fri Oct 30 2015 robert.munteanu@gmail.com
- Update to upstream 1.9.32.10 version
  * Issues Resolved
    + Issue 972 LoadFromFile logs errors on 404s (3d44cc)
    + Issue 992 Segfault in https fetching (b4f4ae9)
    + Issue 1039 Noisy leaked_rewrite_drivers on destruction
    message (58aaa4)
    + Issue 1040 inline_google_font_css no longer works in
    Chrome (01045a)
    + Issue 1043 Source maps set ?PageSpeed=off for .pagespeed.
    sources (9d6d08)
    + Issue 1050 X-Sendfile messages should not be cached (a49af6)
    + Issue 1060 Spurious DownstreamCacheRebeaconingKey
    Warning (0f2a6f)
    + Issue 1068 Empty resources should not be cached.
    (741a86, 3ac019)
    + Issue 1070 Opera Mini should not be sent lazyload_images
    JS (0a90bb)
    + Issue 1078 Image rewriting dcheck-fails on images with
    invalid dimensions (166151)
    + Issue 1087 Critical images js doesn't play well with
    display (f01252)
    + Issue 1106 If-Modified-Since not working with
    IPRO (9ba250)
    + Issue 1109 Can't set MessageBufferSize to 0 (16e9f4)
    + Issue 1116 Won't compile with gcc 4.6.3 (3f9176)
    + Issue 1152 boringssl build fails on suse
    tumbleweed/archlinux (4cbc93)
    + Issue 1048 Apache stuck indefinitely waiting for
    PSOL (84a9de)
    + Issue 1081 Invalid cache entries on aborted
    requests (7a3fab)
- Removed fix-boringssl-compilation.patch, merged upstream
- Removed openssl-linker-flags.patch, merged upstream
* Wed Oct  7 2015 robert.munteanu@gmail.com
- Add fix-boringssl-compilation.patch
* Wed Sep 16 2015 pgajdos@suse.com
- use %%apache_access_syntax_version macro in %%check
* Tue Sep  8 2015 pgajdos@suse.com
- test module with %%apache_test_module_curl
* Fri Jul 31 2015 robert.munteanu@gmail.com
- Update to upstream 1.9.32.4 version
  * Issues Resolved
    + Replace OpenSSL with BoringSSL (does not affect this package)
    + Issue 1094 Source map can be requested with option disabled.
- Removed r4242.patch - included in latest release
- Added openssl-linker-flags.patch to fix build on TW
* Thu Jul 16 2015 pgajdos@suse.com
- Requries: %%{apache_suse_maintenance_mmn}
  This will pull this module to the update (in released distribution)
  when apache maintainer thinks it is good (due api/abi changes).
* Mon Jun 22 2015 pgajdos@suse.com
- fix build with gcc5
  + gcc5.patch
* Thu Jun  4 2015 pgajdos@suse.com
- access configuration conditional
  + apache24-configuration.patch
* Tue Feb 24 2015 robert.munteanu@gmail.com
- added r4242.patch to fix compilation on i586
* Thu Jan 15 2015 robert.munteanu@gmail.com
- Update to upstream 1.9.32.3 version
  * New Features
    + Enabled InPlaceResourceOptimization by default
    + Improved PageSpeed admin site
    + Purge individual URLs from cache
    + Improved debug filter support
    + "Sticky" Query Parameters
    + Signing resource URLs
    + Restrict query params
  * Issues Resolved
    + Issue 1028 Malformed CSS file can cause a hang in CSS parser.
    + Issue 1025 Purge cache UI has problems in admin console.
    + Issue 1012 JS error in rendered_image_dimensions filter when the same image appears multiple times on a page.
    + Issue 1004 Disable SSLv3 and SSLv2 support in serf fetcher.
    + Issue 992 Malformed CSS can lead to unbounded stack depth.
    + Issue 989 IPRO with LoadFromFile on a resource that is already fully optimized serves cc:max-age=300.
    + Issue 986 Default flattening limit is too low.
    + Issue 985 Re-add query params when we get a redirection response.
    + Issue 984 Fix handling of experiment spec, so that options are applied when using the default filters.
    + Issue 982 Defer javascript not working in IE9 or IE11.
    + Issue 978 Blacklist Windows Browser for transcoding to webp.
    + Issue 969 Don't send inline WebP to Chrome/36 on iOS. See issue for workaround fix for both nginx and Apache.
    + Issue 967 Don't relocate scoped style tags in prioritize_critical_css.
    + Issue 965 Don't relocate scoped style tags.
    + Issue 909 Strict mode detection is too conservative.
    + Issue 853 Provide separate filters rewrite_javascript_external and rewrite_javascript_inline.
    + Issue 850 dedup_inlined_images breaks site combined with lazyload_images and defer_javascript.
    + Issue 813 Disable beaconing for bots.
    + Issue 794 Colorize warnings and errors in message_history page.
    + Issue 786 serf_url_async_fetcher.cc error messages using IP instead of domain name.
* Mon Nov  3 2014 pgajdos@suse.com
- call spec-cleaner
- use apache rpm macros
* Fri Oct 31 2014 robert.munteanu@gmail.com
- Update to upstream 1.8.31.5 version
  * Issues Resolved
    + Issue 992 Malformed CSS can lead to unbounded stack depth
    + Issue 1004 Disable SSLv3 and SSLv2 support in serf fetcher
* Tue Aug 12 2014 robert.munteanu@gmail.com
- No longer depend on subversion at build time. Solved by using a
  tarball release instead of gclient
* Fri Aug  8 2014 robert.munteanu@gmail.com
- Rebuilt tarball using openSUSE 12.2
* Thu Aug  7 2014 robert.munteanu@gmail.com
- Update to upstream 1.8.31.4 version
  * New Features
    + New rewrite level OptimizeForBandwidth
    + New admin pages
    + JavaScript source map support
    + Image classification
    + WebP conversion on by default
    + Serve WebP URLs to any browser
    + Inline resources without explicit authorization
    + Downstream cache rebeaconing support
    + Browser-dependent in-place optimization
    + Configurable location for static assets
    + Cache sharing among domains
    + Ability to set options in experiment specs
    + Optional Host: header in MapOriginDomain
    + Fetch HTTPS resources in ngx_pagespeed
    + LazyloadImagesAfterOnload on by default
  * Issues Resolved
    + Issue 106 Inline js files even if they contain </script>.
    + Issue 452 Can't run experiments except on filters and some
    thresholds.
    + Issue 570 Document RewriteDeadlineMs.
    + Issue 586 Track image rewriting time in
    mod_pagespeed_variables.
    + Issue 692 Fixed-case paths broken in domain-mapping
    directives.
    + Issue 752 Issue downstream cache purges only for GET
    requests.
    + Issue 812 SerfThreadFn might compile with the wrong calling
    convention and crash on shutdown.
    + Issue 813 Disable beaconing for bots.
    + Issue 817 WebP transcoding should trigger off Accept:
    headers and issue Vary: Accept.
    + Issue 831 Spriting replaces transparent color with arbitrary
    color.
    + Issue 832 DCHECK failure on static_rewriter test.
    + Issue 840 Deadlock when rewriting resources.
    + Issue 845 etag should not be issued for mismatching content.
    + Issue 846 PageSpeed's cache lookup needs to become
    Vary: Accept aware, at least for WebP.
    + Issue 855 Deadlock when using apache threads with in-place
    rewriting, a threaded mpm, and memcached.
    + Issue 856 Improve error message reporting when shared memory
    segment creation fails.
    + Issue 858 Remove insignificant message: “Default shared
    memory cache: Cache named pagespeed_default_shm already exists”.
    + Issue 863 Cache-Control: no-transform has no effect if
    combined with other values.
    + Issue 871 Apply in-place optimization on first request if
    InPlaceRewriteDeadlineMs is -1 and LoadFromFile is enabled.
    + Issue 881 Changing JS files can make combining/minification
    produce reference errors.
    + Issue 882 Run combine_javascript before rewrite_javascript,
    and have it do the minification inline.
    + Issue 883 Employ image classification to make better
    decisions about lossy conversion.
    + Issue 885 Enabling memcached causes “Waiting for property
    cache” messages and server spinning.
    + Issue 907 Sharedmem “Unable to insert object of size”
    message needs to be demoted and indicate the cache key.
    + Issue 915 Link error on “html_minifier_main” using GCC
    4.9.0 + [Gold] Linker.
    + Issue 918 <style scoped> is translated to
    <link rel="stylesheet" scoped> however there is no browser
    support for the latter.
    + Issue 921 Downstream Caches - PURGE request has a double
    slash.
    + Issue 927 defer_javascript errors in Safari 4.x and 5.0,
    user scripts fail.
    + Issue 928 Allow user defined attributes to override
    spec-defined ones.
    + Issue 937 Increase beacon frequency until there's enough
    data, then decrease it.
    + Issue 938 Check for image criticality at image onload to
    fix carousel display.
* Thu Jul  3 2014 robert.munteanu@gmail.com
- Update to upstream 1.7.30.4 version
  * New Features
    + Default shared memory metadata cache
    + Fetch HTTPS resources for Apache server
    + Fetch HTTPS resources using mod_spdy for Apache server
    + Inline Google Fonts API CSS
    + Preserve URL relativity
    + Optimize multiple URL-valued attributes
    + Implicit cache-lifetime for resources
    + Maximum time for inplace resource rewriting
    + Maximum size of the combined CSS
    + Maximum size of images that will be optimized
    + Minimum size of JPEG images that will be compressed in
    progressive format
    + Resize images to rendered dimensions
    + Better image compression and resizing
  * Configuration defaults updated
    + Default combine_javascript to on (was off)
    + Default convert_png_to_jpeg to on (was off).
  * Issues Resolved
    + Issue 198 Optimize handling of multiple references to the same
    image on a page at different sizes.
    + Issue 376 Image resizing should utilize width/height
    information in CSS classes.
    + Issue 423 Support fetching resources over HTTPS.
    + Issue 441 Filter "make_google_analytics_async" turns benign
    call to deprecated method into a functional error.
    + Issue 466 Provide a way to optimize all resource attributes
    in a tag.
    + Issue 503 Preserve URL relativeness.
    + Issue 627 Quoting of ModPagespeed:noscript insertion broken
    in some browsers.
    + Issue 664 Strip Connection and other hop-by-hop headers when
    saving input resource.
    + Issue 755 Memory leak with 'graceful' restart relating to
    shared memory starting in 1.4.
    + Issue 756 ModifyCachingHeaders should not touch Cache-Control
    headers if downstream-caching is enabled.
    + Issue 757 Make maximum image size configurable.
    + Issue 758 Add configurability for DisableRewriteOnNoTransform
    and system test.
    + Issue 759 Cleanup race in SchedulerBlockingFunction::Block()
    and ::Cancel().
    + Issue 773 Repeat image inlined at low resolution when
    local_storage_cache is enabled.
    + Issue 781 Images are inlined into CSS styles in IE7 if Firefox
    renders them first.
    + Issue 799 Console slow when logfile is large.
    + Issue 803 Metadata cache will reminder not-optimizable for 5
    minutes after rate-limiting drops a fetch.
    + Issue 809 mod_pagespeed disables mod_headers/mod_expires when
    proxying content with cache-control set.
    + Issue 831 Spriting replaces transparent color with arbitrary
    color.
    + Issue 840 Deadlock when rewriting resources.
    + Issue 856 Improve error message reporting when shared memory
    segment creation fails.
    + Issue 857 Avoid insertions (e.g., beacon) at midpoint of the
    document which ought to be at the end of it.
    + Issue 858 Remove insignificant message: Default shared memory
    cache: Cache named pagespeed_default_shm already exists.
    + Issue 860 GoogleFontCssInlineFilter doesn't handle
    protocol-relative URLs correctly.
    + Issue 861 PSOL sample application has dcheck-failure in the
    demo program.
    + Issue 862 mod_pagespeed may have deadlock in property cache
    fetch in IPRO non-proxy mode if memcached is used.
    + Issue 867 Data URLs in CSS become blank after rewriting.
    + Issue 874 Warning messages in log for "ModPagespeed:noscript?".
    + Issue 880 Combining minified JS files can produce invalid
    results when deadline exceeded.
    + Issue 885 Enabling memcached causes "Waiting for property
    cache" messages and server spinning.
    + Issue 896 IPRO on reverse proxy can capture gzipped content
    and serve it to users without content-encoding:gzip.
    + Issue 898 IPRO does not correctly handle resources which
    failed to fetch.
- Dropped fix-pkg-config-opencv-flags.patch as the build no longer
  uses opencv
* Mon Jan  6 2014 tchvatal@suse.com
- Fix typo in condition.
* Sun Dec 29 2013 jweberhofer@weberhofer.at
- Upgrade SVN tree for opensuse 13.1+ versions
* Thu Nov 14 2013 robert.munteanu@gmail.com
- Update to upstream 1.6.29.7
  * New features
    + prioritize_critical_css
    + PageSpeed Console
    + Supporting downstream caches
    + dedup_inlined_images
    + Beacon handling
    + Randomly drop expensive rewrites
    + DisableRewriteOnNoTransform
  * Configuration defaults updated
    + Default AvoidRenamingIntrospectiveJavascript to on (was off)
    + Default ImageInlineMaxBytes to 3072 (was 2048)
    + Default CssImageInlineMaxBytes to 0 (was 2048)
    + Default MaxInlinedPreviewImagesIndex to -1 = unlimited (was 5)
    + Default MinImageSizeLowResolutionBytes to 3072 (was 1024)
    + Default ImageRecompressionQuality to 85 (was -1 = lossless)
    + Default JpegRecompressionQualityForSmallScreens to 70
    (was -1 = lossless)
  + Default WebpRecompressionQuality to 80 (was -1 = lossless)
  + Default WebpRecompressionQualityForSmallScreens to 70 (
    was -1 = lossless)
  * Issues Resolved
    + Issue 109 Make it easy to install on cPanel EasyInstall
    + Issue 199 Multiple references to the same small images
    all get inlined
    + Issue 508 Large numbers get rewritten to scientific notation
    + Issue 644 Improve lazyload behavior
    + Issue 672 Disable setting more than one thread for memcached
    + Issue 675 rewrite_javascript breaks Wordpress /wp-admin/ pages
    with certain common WP plugins.
    + Issue 683 Don't strip Cache-Control:no-store, etc. headers
    + Issue 684 elide_attributes should not remove type=text as
    wordpress uses it in CSS
    + Issue 690 Add originating page URL query-param to beacon URL
    + Issue 700 Image height tag removed when image is embedded
    + Issue 707 PageSpeed lost img tag src value when too busy
    + Issue 709 combine_javascript will kill defer_javascript's
    pagespeed_no_defer attribute
    + Issue 712 JS Canonical Library Map is replicated per vhost
    and per htaccess-subdir.
    + Issue 719 Support random dropping of expensive rewrites
    + Issue 721 New default values for PSOL options
    + Issue 722 rewrite_css should not apply to files with an @import
    in the middle
- Keep .svn directories in the tarball, since they are required at
  build time. Size increased to 82M
* Mon Oct 28 2013 robert.munteanu@gmail.com
- Update to upstream 1.4.26.5
  * Patch-only update, no upstream changelog
* Tue Sep 24 2013 draht@suse.de
- remove .svn .hg directories from tarball. This reduces the size
  of the tarball from 385MB to 59.
* Thu Aug  8 2013 robert.munteanu@gmail.com
- Update to upstream 1.4.26.4
  * Fix for issue 683 : Pagespeed strips cache-control:no-store,
    etc. headers.
* Thu Jun  6 2013 robert.munteanu@gmail.com
- Update to upstream 1.4.26.3
  * New features
  - In-Place Resource Optimization
  - Preserve URLs
  - Shared Memory Metadata Cache
  - Client Options Header
  * Bug fixes
- Drop no longer needed include-unistdh.patch - fixed upstream
* Tue May 21 2013 robert.munteanu@gmail.com
- Updated to upstream 1.3.25.4
  * New features
  - Lossless & transparent WebP support
  - Embedding configuration into resource URLs
  - Better CDN support in MapProxyDomain
  - IE6/IE7 support in lazy load images
  - Shared memory named locks are now on by default
  * New Filters
  - convert_to_webp_lossless
  * Changes to configuration options
  - ModPagespeedAddOptionsToUrls added
  - 3-argument version of ModPagespeedMapProxyDomain added
  - ModPagespeedBeaconUrl arguments no longer required
    to end in ?ets=
  * Bug fixes
- Added include-unistdh.patch to fix compilation
* Thu Mar 21 2013 robert.munteanu@gmail.com
- Update to upstream 1.2.24.1
  * New features
  - Proxying and optimizing resources from trusted domains
  - pagespeed_no_transform attribute for images
  - convert_jpeg_to_progressive is now a core filter
  - Standalone JS Minification
  - Better handling of CSS
  - Show configuration from /mod_pagespeed_statistics
  * New Filters
  - insert_dns_prefetch
  - canonicalize_javascript_libraries
  * New configuration options
  - ModPagespeedCssFlattenMaxBytes
  - ModPagespeedForbidFilters
  - ModPagespeedForbidAllDisabledFilters
  - ModPagespeedMemcachedTimeoutUs
  - ModPagespeedRewriteDeadlinePerFlushMs
  - ModPagespeedMaxCacheableContentLength
  * Bug fixes
* Sun Dec 16 2012 robert.munteanu@gmail.com
- Update packaging to reflect simplification of cache directory
  structure.
* Thu Dec  6 2012 robert.munteanu@gmail.com
- Remove %%{_smp_mflags} to debug failures on OBS
* Thu Dec  6 2012 robert.munteanu@gmail.com
- Update to upstream 1.1.23.2
  - New features
  - memcached supports
  - SPDY configuration support
  - CSS3 support
  - Per-Vhost statistics
  - Expanded default filter set
  - Standalone CSS parser
  - New filters
  - extend_cache_pdfs
  - fallback_rewrite_css_urls
  - pedantic
  - Enhanced image rewriter control
  - New configuration options
  - ModPagespeedCssFlattenMaxBytes
  - ModPagespeedCustomFetchHeader
  - <ModPagespeedIf>
  - ModPagespeedImageRecompressionQuality
  - ModPagespeedImageWebpRecompressionQuality
  - ModPagespeedLoadFromFileMatch
  - ModPagespeedMemcachedServers
  - ModPagespeedMemcachedThreads
  - ModPagespeedFileCacheInodeLimit
  - ModPagespeedInheritVHostConfig
  - ModPagespeedUsePerVHostStatistics
  - ModPagespeedRespectXForwardedProto
  - Bug fixes
* Mon Oct 15 2012 idonmez@suse.com
- Build depend on python-base instead of python
* Fri Oct 12 2012 robert.munteanu@gmail.com
- Update to upstream 1.0.22.7
  - This release is functionally identical to release 0.10.22.7
* Sun Sep 30 2012 robert@localhost
- Updated to upstream 0.10.22.7
  - This release adds a single new pagespeed.conf option,
  ModPagespeedDangerPermitFetchFromUnknownHosts, which disables
  one of the security fixes from 0.10.22.6.
* Wed Sep 12 2012 robert.munteanu@gmail.com
- Updated to upstream 0.10.22.6
  - Fix for CVE-2012-4001, a problem with validation of own host
  name
  - Fix for CVE-2012-4360, a cross-site scripting attack
- Use license name from SPDX
- Removed upstreamed fix-issue-453.patch
- Removed upstreamed fix-unistd-include.patch
* Tue Aug 14 2012 robert.munteanu@gmail.com
- Updated to upstream 0.10.22.3
  - support for Apache 2.4
  - ability to flush the cache of a running server by touching a file
  in the cache directory
  - new filters
  - miscellaneous fixes and improvements
- removed all upstreamed patches
- added new patches for building with gcc 4.7.x and system opencv
* Thu Apr 26 2012 robert.munteanu@gmail.com
- Fix building against gcc 4.7
* Fri Apr  6 2012 robert.munteanu@gmail.com
- Initial version based on 0.10.21.2
